//
//  ViewController.swift
//  Angry Birds en la Tierra y la Luna
//
//  Created by Santiago Pavón Gómez on 29/9/16.
//  Copyright © 2016 UPM. All rights reserved.
//

import UIKit

class ViewController: UIViewController, TrajectoryViewDataSource {

    @IBOutlet weak var speedSlider: UISlider!
    @IBOutlet weak var angleSlider: UISlider!
    @IBOutlet weak var distanceSlider: UISlider!
    @IBOutlet weak var scaleSlider: UISlider!
    
    @IBOutlet weak var speedValue: UILabel!
    @IBOutlet weak var angleValue: UILabel!
    @IBOutlet weak var distanceValue: UILabel!
    @IBOutlet weak var scaleValue: UILabel!
    
    
    @IBOutlet weak var earthTrajView: TrajectoryView!
    
    var earthTrajModel: TrajectoryModel!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        earthTrajModel = TrajectoryModel(name: "La Tierra", gravity: 9.80665)
        
        earthTrajView.dataSource = self
        
        speedSlider.sendActions(for: .valueChanged)
        angleSlider.sendActions(for: .valueChanged)
        distanceSlider.sendActions(for: .valueChanged)
        scaleSlider.sendActions(for: .valueChanged)
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    
    // MARK: - Slider Actions
    
    @IBAction func speedChanged(_ sender: UISlider) {
        earthTrajModel.speed = Double(sender.value)
        
        speedValue.text = String(format: "%.2f m/s", arguments: [sender.value])
        
        earthTrajView.setNeedsDisplay()
    }
    
    @IBAction func angleChanged(_ sender: UISlider) {
        earthTrajModel.angle = Double(sender.value)
        
        angleValue.text = String(format: "%.2f rad", arguments: [sender.value])
        
        earthTrajView.setNeedsDisplay()
    }
    
    @IBAction func distanceChanged(_ sender: UISlider) {
        distanceValue.text = String(format: "%.2f m", arguments: [sender.value])
        
        earthTrajView.distanceToTarget = Double(sender.value)
    }
    
    @IBAction func scaleChanged(_ sender: UISlider) {
        let scale = Double(sender.value)
        scaleValue.text = String(format: "%.2f mpp", arguments: [scale])
        earthTrajView.scale = scale
    }
    
    
    // MARK: - TrajectoryViewDataSource {
    
    func startTime(for trajectoryView: TrajectoryView) -> Double {
        return 0
    }
    
    func endTime(for trajectoryView: TrajectoryView) -> Double {
        return earthTrajModel.timeToTarget()
    }
    
    func position(for trajectoryView: TrajectoryView, at time: Double) -> Position {
        
            let distance = earthTrajModel.distanceAtTime(time: time)
            let alture = earthTrajModel.altureAtTime(time: time)
            return Position(distance: distance, alture: alture)
    }

}

